@@ -31,6 +31,8 @@
 
 using namespace std;
 
+MemoryTally gMemTally;
+
 static bool showVersion = false; // just print version and quit?
 int verbose             = 0;  // be talkative
 static int names_only   = 0;  // just print the sequence names in the index
@@ -96,7 +98,7 @@ static void printUsage(ostream& out) {
     << "  --ss               Print splice sites" << endl
     << "  --ss-all           Print splice sites including those not in the global index" << endl
     << "  --exon             Print exons" << endl
-	<< "  -e/--bt2-ref       Reconstruct reference from ." << gfm_ext << " (slow, preserves colors)" << endl
+	<< "  -e/--ht2-ref       Reconstruct reference from ." << gfm_ext << " (slow, preserves colors)" << endl
 	<< "  -v/--verbose       Verbose output (for debugging)" << endl
 	<< "  -h/--help          print detailed description of tool and its options" << endl
 	<< "  --help             print this usage message" << endl
@@ -365,7 +367,8 @@ static void print_snps(
                      verbose,              // be talkative?
                      verbose,              // be talkative at startup?
                      false,                // pass up memory exceptions?
-                     false);               // sanity check?
+                     false,                // sanity check?
+                     false);               // use haplotypes?
     gfm.loadIntoMemory(
                        -1,     // need entire reverse
                        true,   // load SA sample
@@ -442,11 +445,12 @@ static void print_splicesites(
                      false,                // load SA sample?
                      false,                // load ftab?
                      false,                // load rstarts?
-                     true,                // load splice sites?
+                     true,                 // load splice sites?
                      verbose,              // be talkative?
                      verbose,              // be talkative at startup?
                      false,                // pass up memory exceptions?
-                     false);               // sanity check?
+                     false,                // sanity check?
+                     false);               // use haplotypes?
     gfm.loadIntoMemory(
                        -1,     // need entire reverse
                        true,   // load SA sample
@@ -517,7 +521,8 @@ static void print_exons(
                      verbose,              // be talkative?
                      verbose,              // be talkative at startup?
                      false,                // pass up memory exceptions?
-                     false);               // sanity check?
+                     false,                // sanity check?
+                     false);               // use haplotypes?
     gfm.loadIntoMemory(
                        -1,     // need entire reverse
                        true,   // load SA sample
@@ -586,11 +591,12 @@ static void print_index_summary(
                      false,                // load SA sample?
                      false,                // load ftab?
                      false,                // load rstarts?
-                     true,                // load splice sites?
+                     true,                 // load splice sites?
                      verbose,              // be talkative?
                      verbose,              // be talkative at startup?
                      false,                // pass up memory exceptions?
-                     false);               // sanity check?
+                     false,                // sanity check?
+                     false);               // use haplotypes?
 	EList<string> p_refnames;
 	readEbwtRefnames<index_t>(fname, p_refnames);
     cout << "Index version" << "\t2." << major << '.' << minor;
@@ -672,7 +678,8 @@ static void driver(
                                        false,                // be talkative?
                                        false,                // be talkative at startup?
                                        false,                // pass up memory exceptions?
-                                       false);               // sanity check?
+                                       false,                // sanity check?
+                                       false);               // use haplotypes?
         
         gfm.loadIntoMemory(
                            -1,     // need entire reverse
